# Beginner Start Here

Start with the workspace [README.md](../README.md).

It explains:

- how to create or activate `xenv`
- how to activate `xenv`
- how to install Codex on Ubuntu or Debian
- how to log into Codex and Claude
- what `repos/`, `workspace/`, and `ai/` are
- how to use `scix sync`
